@@ -108,10 +108,8 @@ Engine::Engine(QObject *parent)
 {
     qRegisterMetaType<FrequencySpectrum>("FrequencySpectrum");
     qRegisterMetaType<WindowFunction>("WindowFunction");
-    CHECKED_CONNECT(&m_spectrumAnalyser,
-                    SIGNAL(spectrumChanged(FrequencySpectrum)),
-                    this,
-                    SLOT(spectrumChanged(FrequencySpectrum)));
+    connect(&m_spectrumAnalyser, QOverload<const FrequencySpectrum&>::of(&SpectrumAnalyser::spectrumChanged),
+            this, QOverload<const FrequencySpectrum&>::of(&Engine::spectrumChanged));
 
     // This code might misinterpret things like "-something -category".  But
     // it's unlikely that that needs to be supported so we'll let it go.
@@ -243,16 +241,17 @@ void Engine::startRecording()
             setRecordPosition(0, true);
             stopPlayback();
             m_mode = QAudio::AudioInput;
-            CHECKED_CONNECT(m_audioInput, SIGNAL(stateChanged(QAudio::State)),
-                            this, SLOT(audioStateChanged(QAudio::State)));
-            CHECKED_CONNECT(m_audioInput, SIGNAL(notify()),
-                            this, SLOT(audioNotify()));
+            connect(m_audioInput, &QAudioInput::stateChanged,
+                    this, &Engine::audioStateChanged);
+            connect(m_audioInput, &QAudioInput::notify,
+                    this, &Engine::audioNotify);
+
             m_count = 0;
             m_dataLength = 0;
             emit dataLengthChanged(0);
             m_audioInputIODevice = m_audioInput->start();
-            CHECKED_CONNECT(m_audioInputIODevice, SIGNAL(readyRead()),
-                            this, SLOT(audioDataReady()));
+            connect(m_audioInputIODevice, &QIODevice::readyRead,
+                    this, &Engine::audioDataReady);
         }
     }
 }
@@ -275,10 +274,11 @@ void Engine::startPlayback()
             setPlayPosition(0, true);
             stopRecording();
             m_mode = QAudio::AudioOutput;
-            CHECKED_CONNECT(m_audioOutput, SIGNAL(stateChanged(QAudio::State)),
-                            this, SLOT(audioStateChanged(QAudio::State)));
-            CHECKED_CONNECT(m_audioOutput, SIGNAL(notify()),
-                            this, SLOT(audioNotify()));
+            connect(m_audioOutput, &QAudioOutput::stateChanged,
+                    this, &Engine::audioStateChanged);
+            connect(m_audioOutput, &QAudioOutput::notify,
+                    this, &Engine::audioNotify);
+
             m_count = 0;
             if (m_file) {
                 m_file->seek(0);
@@ -569,15 +569,17 @@ bool Engine::selectFormat()
             sampleRatesList += m_audioInputDevice.supportedSampleRates();
 
         sampleRatesList += m_audioOutputDevice.supportedSampleRates();
-        sampleRatesList = sampleRatesList.toSet().toList(); // remove duplicates
-        qSort(sampleRatesList);
+        std::sort(sampleRatesList.begin(), sampleRatesList.end());
+        const auto uniqueRatesEnd = std::unique(sampleRatesList.begin(), sampleRatesList.end());
+        sampleRatesList.erase(uniqueRatesEnd, sampleRatesList.end());
         ENGINE_DEBUG << "Engine::initialize frequenciesList" << sampleRatesList;
 
         QList<int> channelsList;
         channelsList += m_audioInputDevice.supportedChannelCounts();
         channelsList += m_audioOutputDevice.supportedChannelCounts();
-        channelsList = channelsList.toSet().toList();
-        qSort(channelsList);
+        std::sort(channelsList.begin(), channelsList.end());
+        const auto uniqueChannelsEnd = std::unique(channelsList.begin(), channelsList.end());
+        channelsList.erase(uniqueChannelsEnd, channelsList.end());
         ENGINE_DEBUG << "Engine::initialize channelsList" << channelsList;
 
         QAudioFormat format;
@@ -585,12 +587,11 @@ bool Engine::selectFormat()
         format.setCodec("audio/pcm");
         format.setSampleSize(16);
         format.setSampleType(QAudioFormat::SignedInt);
-        int sampleRate, channels;
-        foreach (sampleRate, sampleRatesList) {
+        for (int sampleRate : qAsConst(sampleRatesList)) {
             if (foundSupportedFormat)
                 break;
             format.setSampleRate(sampleRate);
-            foreach (channels, channelsList) {
+            for (int channels : qAsConst(channelsList)) {
                 format.setChannelCount(channels);
                 const bool inputSupport = m_generateTone ||
                                           m_audioInputDevice.isFormatSupported(format);
@@ -752,8 +753,7 @@ void Engine::createOutputDir()
     // Ensure output directory exists and is empty
     if (m_outputDir.exists()) {
         const QStringList files = m_outputDir.entryList(QDir::Files);
-        QString file;
-        foreach (file, files)
+        for (const QString &file : files)
             m_outputDir.remove(file);
     } else {
         QDir::current().mkdir("output");
