@@ -78,6 +78,7 @@ void Window::initializeGL()
     m_backgroundTexture->setMinificationFilter(QOpenGLTexture::Nearest);
     m_backgroundImageSize = backgroundImage.size();
     m_textureBlitter.create();
+    m_compositor->create(); // the compositor's hardware integration may depend on GL
 }
 
 void Window::drawBackground()
@@ -124,7 +125,8 @@ void Window::paintGL()
     functions->glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
     GLenum currentTarget = GL_TEXTURE_2D;
-    Q_FOREACH (View *view, m_compositor->views()) {
+    const auto views = m_compositor->views();
+    for (View *view : views) {
         if (view->isCursor())
             continue;
         auto texture = view->getTexture();
@@ -159,7 +161,8 @@ void Window::paintGL()
 View *Window::viewAt(const QPointF &point)
 {
     View *ret = nullptr;
-    Q_FOREACH (View *view, m_compositor->views()) {
+    const auto views = m_compositor->views();
+    for (View *view : views) {
         if (view == m_dragIconView)
             continue;
         QRectF geom(view->position(), view->size());
@@ -180,7 +183,7 @@ void Window::startResize(int edge, bool anchored)
     m_grabState = ResizeGrab;
     m_resizeEdge = edge;
     m_resizeAnchored = anchored;
-    m_resizeAnchorPosition = getAnchorPosition(m_mouseView->position(), edge, m_mouseView->surface()->size());
+    m_resizeAnchorPosition = getAnchorPosition(m_mouseView->position(), edge, m_mouseView->surface()->destinationSize());
 }
 
 void Window::startDrag(View *dragIcon)
