@@ -53,10 +53,12 @@
 
 int main(int argc, char *argv[])
 {
+    QCoreApplication::setOrganizationName("QtExamples");
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication app(argc, argv);
 
     MainWindow mainWindow;
+    mainWindow.resize(1024, 768);
     mainWindow.show();
 
     return app.exec();
